@@ -11,16 +11,16 @@ from .environment import (
     is_windows,
     is_apple,
     is_ish_alpine,
-    pyinstaller,
+    is_pyinstaller,
     is_frozen,
     is_elf,
     is_pyz,
     is_windows_portable_executable,
     is_macos_executable,
     is_pipx,
-    is_interactive_terminal,
+    interactive_terminal_is_available,
     web_browser_is_available,
-    open_text_file_in_default_app,
+    edit_textfile,
 )
 
 # Optional: Set __all__ for explicit documentation and cleaner imports
@@ -35,14 +35,14 @@ __all__ = [
     'is_windows',
     'is_apple',
     'is_ish_alpine',
-    'pyinstaller',
+    'is_pyinstaller',
     'is_frozen',
     'is_elf',
     'is_pyz',
     'is_windows_portable_executable',
     'is_macos_executable',
     'is_pipx',
-    'is_interactive_terminal',
+    'interactive_terminal_is_available',
     'web_browser_is_available',
-    'open_text_file_in_default_app',
-]
\ No newline at end of file
+    'edit_textfile',
+]
