@@ -12,8 +12,7 @@ import shutil
 from pathlib import Path
 import subprocess
 import io
-
-from pipeline.helpers import check_if_zip
+import zipfile
 
 # Global cache for tkinter and matplotlib (mpl) availability
 _TKINTER_AVAILABILITY: bool | None = None
@@ -212,7 +211,7 @@ def is_ish_alpine() -> bool:
 
 # --- BUILD AND EXECUTABLE CHECKS ---
     
-def pyinstaller():
+def is_pyinstaller():
     """Detects if the Python script is running as a 'frozen' in the course of generating a PyInstaller binary executable."""
     # If the app is frozen AND has the PyInstaller-specific temporary folder path
     return is_frozen() and hasattr(sys, '_MEIPASS')
@@ -277,7 +276,7 @@ def is_pyz(exec_path: Path=None, debug=False) -> bool:
     if not str(exec_path).endswith(".pyz"):
         return False
     
-    if not check_if_zip():
+    if not _check_if_zip():
         return False
 
 def is_windows_portable_executable(exec_path: Path = None, debug=False) -> bool:
@@ -449,22 +448,57 @@ def web_browser_is_available() -> bool:
         return False
     
 # --- LAUNCH MECHANISMS BASED ON ENVIRONMENT ---
-def open_text_file_in_default_app(filepath):
-    """Opens a file with its default application based on the OS."""
-    if is_windows():
-        os.startfile(filepath)
-    elif is_termux():
-        subprocess.run(['nano', filepath])
-    elif is_ish_alpine():
-        subprocess.run(['apk','add', 'nano'], stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)
-        subprocess.run(['nano', filepath])
-    elif is_linux():
-        subprocess.run(['xdg-open', filepath])
-    elif is_apple():
-        subprocess.run(['open', filepath])
-    else:
-        print("Unsupported operating system.")
+def edit_textfile(filepath) -> None:
+#def open_text_file_for_editing(filepath):
+    """
+    Opens a file with the environment's default application (Windows, Linux, macOS)
+    or a guaranteed console editor (nano) in constrained environments (Termux, iSH)
+    after ensuring line-ending compatibility.
+    """
+    try:
+        if is_windows():
+            os.startfile(filepath)
+        elif is_termux():
+    	    # Install dependencies if missing (Termux pkg returns non-zero if already installed, so no check=True)
+    	    subprocess.run(['pkg','install', 'dos2unix', 'nano'], stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)
+    	    _run_dos2unix(filepath)
+    	    subprocess.run(['nano', filepath])
+        elif is_ish_alpine():
+            # Install dependencies if missing (apk returns 0 if already installed, so check=True is safe)
+    	    subprocess.run(['apk','add', 'dos2unix'], stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL, check=True)
+    	    subprocess.run(['apk','add', 'nano'], stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL, check=True)
+    	    _run_dos2unix(filepath)
+    	    subprocess.run(['nano', filepath])
+    	# --- Standard Unix-like Systems (Conversion + Default App) ---
+        elif is_linux():
+    	    _run_dos2unix(filepath) # Safety conversion for user-defined console apps
+    	    subprocess.run(['xdg-open', filepath])
+        elif is_apple():
+    	    _run_dos2unix(filepath) # Safety conversion for user-defined console apps
+    	    subprocess.run(['open', filepath])
+        else:
+    	    print("Unsupported operating system.")
+    except Exception as e:
+	    print("The file could not be opened for editing in the current environment. Known failure points: Pydroid3")
 
+    """Why Not Use check=True on Termux:
+    The pkg utility in Termux is a wrapper around Debian's apt. When you run pkg install <package>, if the package is already installed, the utility often returns an exit code of 100 (or another non-zero value) to indicate that no changes were made because the package was already present.
+    """
+    
+def _run_dos2unix(filepath):
+    """Attempt to run dos2unix, failing silently if not installed."""
+    try:
+        # We rely on shutil.which not being needed, as this is a robust built-in utility on most targets
+        # The command won't raise an exception unless the process itself fails, not just if the utility isn't found.
+        # We also don't use check=True here to allow silent failure if the utility is missing (e.g., minimalist Linux).
+        subprocess.run(['dos2unix', filepath], stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)
+    except FileNotFoundError:
+        # This will be raised if 'dos2unix' is not on the system PATH
+        pass 
+    except Exception:
+        # Catch other subprocess errors (e.g. permission issues)
+        pass
+        
 def _get_pipx_paths():
     """
     Returns the configured/default pipx binary and home directories.
@@ -490,3 +524,13 @@ def _get_pipx_paths():
         pipx_venv_base = Path.home() / '.local' / 'share' / 'pipx' / 'venvs'
 
     return pipx_bin_path, pipx_venv_base.resolve()
+
+
+def _check_if_zip(file_path: str | Path) -> bool:
+    """Checks if the file at the given path is a valid ZIP archive."""
+    try:
+        return zipfile.is_zipfile(file_path)
+    except Exception:
+        # Handle cases where the path might be invalid, or other unexpected errors
+        return False
+        
